@@ -13,7 +13,7 @@ from dask.distributed import TimeoutError
 from distributed import wait
 from dask import config
 import coiled
-from chess_util import ChessUtil
+from .chess_util import ChessUtil
 
 
 class ChessDaskCluster:
